# -*- coding: utf-8 -*-
##----------------------------------------------------------------------
## reportfree Test
##----------------------------------------------------------------------
## Copyright (C) 2007-2009 The NOC Project
## See LICENSE for details
##----------------------------------------------------------------------
from noc.lib.test import ReportApplicationTestCase

class reportfreeTestCase(ReportApplicationTestCase):
    posts=[{"vrf":1,"prefix":"0.0.0.0/0","afi":"4"}]
